@@ -43,7 +43,7 @@ const vpc = new ec2.Vpc();
 new AwsInterfaceEndpoints(this, 'EcrInterfaceEndpoint', {
   vpc,
   services: [
-    ec2.InterfaceVpcEndpointAwsService.ECR_DOCKER,
+    { id: 'EcrDocker', ec2.InterfaceVpcEndpointAwsService.ECR_DOCKER },
   ],
 });
 ```
@@ -80,7 +80,7 @@ new AwsInterfaceEndpoints(this, 'EcrInterfaceEndpoint', {
   vpc,
   open: false,
   services: [
-    ec2.InterfaceVpcEndpointAwsService.ECR_DOCKER,
+    { id: 'EcrDocker', ec2.InterfaceVpcEndpointAwsService.ECR_DOCKER },
   ],
 });
 ```
@@ -97,7 +97,7 @@ define instance: ec2.Instance;
 
 const endpoints = AwsInterfaceEndpoints.fromAttributes(this, 'EcrInterfaceEndpoint', {
   services: [
-    ec2.InterfaceVpcEndpointAwsService.ECR_DOCKER,
+    { id: 'EcrDocker', ec2.InterfaceVpcEndpointAwsService.ECR_DOCKER },
   ],
 });
 
@@ -130,6 +130,63 @@ import aws_cdk.aws_ec2
 import constructs
 
 
+@jsii.data_type(
+    jsii_type="@alma-cdk/aws-interface-endpoints.AwsServiceConfig",
+    jsii_struct_bases=[],
+    name_mapping={"id": "id", "service": "service"},
+)
+class AwsServiceConfig:
+    def __init__(
+        self,
+        *,
+        id: builtins.str,
+        service: aws_cdk.aws_ec2.InterfaceVpcEndpointAwsService,
+    ) -> None:
+        '''
+        :param id: 
+        :param service: 
+
+        :stability: experimental
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(AwsServiceConfig.__init__)
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument service", value=service, expected_type=type_hints["service"])
+        self._values: typing.Dict[str, typing.Any] = {
+            "id": id,
+            "service": service,
+        }
+
+    @builtins.property
+    def id(self) -> builtins.str:
+        '''
+        :stability: experimental
+        '''
+        result = self._values.get("id")
+        assert result is not None, "Required property 'id' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def service(self) -> aws_cdk.aws_ec2.InterfaceVpcEndpointAwsService:
+        '''
+        :stability: experimental
+        '''
+        result = self._values.get("service")
+        assert result is not None, "Required property 'service' is missing"
+        return typing.cast(aws_cdk.aws_ec2.InterfaceVpcEndpointAwsService, result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "AwsServiceConfig(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 @jsii.interface(jsii_type="@alma-cdk/aws-interface-endpoints.IAwsInterfaceEndpoints")
 class IAwsInterfaceEndpoints(typing_extensions.Protocol):
     '''
@@ -184,7 +241,7 @@ class LookupProps:
     def __init__(
         self,
         *,
-        services: typing.Sequence[aws_cdk.aws_ec2.InterfaceVpcEndpointAwsService],
+        services: typing.Sequence[typing.Union[AwsServiceConfig, typing.Dict[str, typing.Any]]],
         export_prefix: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -204,13 +261,13 @@ class LookupProps:
             self._values["export_prefix"] = export_prefix
 
     @builtins.property
-    def services(self) -> typing.List[aws_cdk.aws_ec2.InterfaceVpcEndpointAwsService]:
+    def services(self) -> typing.List[AwsServiceConfig]:
         '''
         :stability: experimental
         '''
         result = self._values.get("services")
         assert result is not None, "Required property 'services' is missing"
-        return typing.cast(typing.List[aws_cdk.aws_ec2.InterfaceVpcEndpointAwsService], result)
+        return typing.cast(typing.List[AwsServiceConfig], result)
 
     @builtins.property
     def export_prefix(self) -> typing.Optional[builtins.str]:
@@ -251,7 +308,7 @@ class SessionManagerEndpointProps:
     def __init__(
         self,
         *,
-        services: typing.Sequence[aws_cdk.aws_ec2.InterfaceVpcEndpointAwsService],
+        services: typing.Sequence[typing.Union[AwsServiceConfig, typing.Dict[str, typing.Any]]],
         vpc: aws_cdk.aws_ec2.IVpc,
         export_prefix: typing.Optional[builtins.str] = None,
         open: typing.Optional[builtins.bool] = None,
@@ -292,13 +349,13 @@ class SessionManagerEndpointProps:
             self._values["subnets"] = subnets
 
     @builtins.property
-    def services(self) -> typing.List[aws_cdk.aws_ec2.InterfaceVpcEndpointAwsService]:
+    def services(self) -> typing.List[AwsServiceConfig]:
         '''
         :stability: experimental
         '''
         result = self._values.get("services")
         assert result is not None, "Required property 'services' is missing"
-        return typing.cast(typing.List[aws_cdk.aws_ec2.InterfaceVpcEndpointAwsService], result)
+        return typing.cast(typing.List[AwsServiceConfig], result)
 
     @builtins.property
     def vpc(self) -> aws_cdk.aws_ec2.IVpc:
@@ -385,7 +442,7 @@ class AwsInterfaceEndpoints(
         scope: constructs.Construct,
         id: builtins.str,
         *,
-        services: typing.Sequence[aws_cdk.aws_ec2.InterfaceVpcEndpointAwsService],
+        services: typing.Sequence[typing.Union[AwsServiceConfig, typing.Dict[str, typing.Any]]],
         vpc: aws_cdk.aws_ec2.IVpc,
         export_prefix: typing.Optional[builtins.str] = None,
         open: typing.Optional[builtins.bool] = None,
@@ -426,7 +483,7 @@ class AwsInterfaceEndpoints(
         scope: constructs.Construct,
         id: builtins.str,
         *,
-        services: typing.Sequence[aws_cdk.aws_ec2.InterfaceVpcEndpointAwsService],
+        services: typing.Sequence[typing.Union[AwsServiceConfig, typing.Dict[str, typing.Any]]],
         export_prefix: typing.Optional[builtins.str] = None,
     ) -> IAwsInterfaceEndpoints:
         '''
@@ -462,17 +519,16 @@ class AwsInterfaceEndpoints(
 
     @jsii.python.classproperty
     @jsii.member(jsii_name="SessionManagerConnect")
-    def SESSION_MANAGER_CONNECT(
-        cls,
-    ) -> typing.List[aws_cdk.aws_ec2.InterfaceVpcEndpointAwsService]:
+    def SESSION_MANAGER_CONNECT(cls) -> typing.List[AwsServiceConfig]:
         '''
         :stability: experimental
         '''
-        return typing.cast(typing.List[aws_cdk.aws_ec2.InterfaceVpcEndpointAwsService], jsii.sget(cls, "SessionManagerConnect"))
+        return typing.cast(typing.List[AwsServiceConfig], jsii.sget(cls, "SessionManagerConnect"))
 
 
 __all__ = [
     "AwsInterfaceEndpoints",
+    "AwsServiceConfig",
     "IAwsInterfaceEndpoints",
     "LookupProps",
     "SessionManagerEndpointProps",
